# RelaxiFI
A python package to model the relaxation stretching of olivine-hosted FI by creep
            How to Apply These Terms to Your New Programs


Copyright (C) <2023>  <Charlotte Devitre>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version. 
You cannot use RelaxiFI to create closed source software.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.